package exception

import (
	"errors"
	"git.168cad.top/zhengqiuyun/rym-util/log"
	"github.com/go-playground/validator/v10"
	"reflect"
	"strings"
)

func ThrowsErr(err error) {
	if err != nil {
		log.Error(err.Error())
		panic(err)
	}
}

func ThrowsValid(err error, r interface{}) {
	if err != nil {
		switch err.(type) {
		case validator.ValidationErrors:
			e := (err).(validator.ValidationErrors)
			errMsg := getError(e, r)
			panic(errors.New(errMsg))
			break
		default:
			panic(err)
			break
		}
	}
}

// 自定义错误消息
func getError(errs validator.ValidationErrors, r interface{}) string {
	s := reflect.TypeOf(r)
	for _, fieldError := range errs {
		filed, _ := s.FieldByName(fieldError.Field())
		// 获取统一错误消息
		errText := filed.Tag.Get("msg")
		if errText != "" {
			return errText
		}
		jsonTag := filed.Tag.Get("json")
		fieldName := ""
		if jsonTag == "" {
			fieldName = fieldError.Field()
		} else {
			fieldName = strings.Split(jsonTag, ",")[0]
		}
		return fieldName + " " + fieldError.Tag()
	}
	return ""
}

type DError struct {
	Err string
}

func (e *DError) Error() string {
	return e.Err
}
func ThrowsErrS(err string) {
	if &err != nil && err != "" {
		log.Error(err)
		panic(DError{Err: err})
	}
}

func AssertThrowableErr(throwable bool, err error) {
	if throwable {
		log.Error(err.Error())
		panic(err)
	}
}
func AssertThrowable(throwable bool, err string) {
	if throwable {
		log.Error(err)
		panic(DError{Err: err})
	}
}
